#!/bin/sh
# ----------------------------------------------------------------------------
# /var/install/dialog.d/CUPS_YESNO_CUI.sh - script dialog for ece
#
# Creation:     2023-11-24 hbfl 
# Last update:  $Id: CUPS_YESNO_SECONDS_CUI.sh 107758 2023-11-24 11:07:57Z hbfl $
#
# Copyright (c) 2023-2024 the eisfair team, team(at)eisfair(dot)org
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

. /var/install/include/cuilib
. /var/install/include/ecelib

#----------------------------------------------------------------------------
# control constants
#----------------------------------------------------------------------------

IDC_CHECK='1'
IDC_LISTBOX='10'
IDC_EDIT_PATTERN='11'
IDC_BUTOK='100'
IDC_BUTCANCEL='100'

#----------------------------------------------------------------------------
# global variables
#----------------------------------------------------------------------------
valueBackup=''

#----------------------------------------------------------------------------
# is_pattern
#    check if parameter is not empty
#----------------------------------------------------------------------------

is_pattern()
{
    echo "$1" | grep -E '.+'
}

#----------------------------------------------------------------------------
# cancel_button_clicked
#         $p2 --> dialog window handle
#         $p3 --> control's window handle
#----------------------------------------------------------------------------

cancel_button_clicked()
{
    # use the backup
    value=${valueBackup}
    valueBackup=''

    cui_window_close "${p2}" "${IDCANCEL}"
    cui_return 1
}

#----------------------------------------------------------------------------
# ok_button_clicked
#         $p2 --> dialog window handle
#         $p3 --> control's window handle
#----------------------------------------------------------------------------

ok_button_clicked()
{
    local dlg="${p2}"
    local check=''
    local lb=''
    local can_close=0

    # proof if listbox or pattern
    cui_window_getctrl ${dlg} ${IDC_CHECK}
    check="${p2}"
    cui_checkbox_getcheck ${check}
    val="${p2}"

    if [ ${val} = 1 ]
    then
        # get pattern
        cui_window_getctrl ${dlg} ${IDC_EDIT_PATTERN}
        check="${p2}"
        cui_edit_gettext "${check}"
        if is_pattern "${p2}"
        then
            can_close=1
        else
            cui_message ${dlg} "Value not empty!" "Error" "${MB_ERROR}"
        fi
   else
       # get value fom listbox
        cui_window_getctrl ${dlg} ${IDC_LISTBOX}
        lb="${p2}"
        # get index
        cui_listbox_getsel "${lb}"
        index="${p2}"
        cui_listbox_get "${lb}" ${index}
        can_close=1
    fi

    # return value
    value="${p2}"
    if [ ${can_close} = 1 ]
    then
        cui_window_close "${dlg}" "${IDOK}"
    fi

    cui_return 1
}

#----------------------------------------------------------------------------
# checkbox_clicked
#         $p2 --> dialog window handle
#         $p3 --> control's window handle
#----------------------------------------------------------------------------

checkbox_clicked()
{
    local dlg="${p2}"
    local chb="${p3}"

    cui_checkbox_getcheck ${chb}
    local val="${p2}"

    if [ ${val} = 1 ]
    then
        # hide listbox
        cui_window_getctrl     ${dlg} ${IDC_LISTBOX}
        cui_window_hide        ${p2}  1
        # enable pattern
        cui_window_getctrl     ${dlg} ${IDC_EDIT_PATTERN}
        cui_window_hide        ${p2}  0
        cui_window_setfocus    ${p2}
    else
        # unhide listbox
        cui_window_getctrl     ${dlg} ${IDC_LISTBOX}
        cui_window_hide        ${p2}  0
        # disable pattern
        cui_window_getctrl     ${dlg} ${IDC_EDIT_PATTERN}
        cui_window_hide        ${p2}  1
    fi

    cui_return 1
}

#----------------------------------------------------------------------------
# listbox_changed
#         $p2 --> dialog window handle
#         $p3 --> control's window handle
#----------------------------------------------------------------------------

listbox_changed()
{
    cui_return 1
}

#----------------------------------------------------------------------------
# testdlg_create_hook
#         $p2 --> dialog window handle
#----------------------------------------------------------------------------

testdlg_create_hook()
{
    valueBackup=${value}
    local dlg="${p2}"
    local ctrl

    local setStyle=${CWS_HIDDEN}
    local setChecked=0
    local setValue=''
    if is_pattern "${value}"
    then
       setStyle=${CWS_NONE}
       setChecked=1
       setValue="${value}"
    fi

    # create checkbox
    if cui_checkbox_new "${dlg}" "Value" 1 1 11 1 ${IDC_CHECK} ${CWS_NONE} ${CWS_NONE}
    then
        ctrl="${p2}"
        cui_checkbox_callback  "${ctrl}" "${CHECKBOX_CLICKED}" "${dlg}" checkbox_clicked
        cui_checkbox_setcheck  "${ctrl}" ${setChecked}
        cui_window_create      "${ctrl}"
    fi

    # create edit
    if cui_edit_new "${dlg}" "" 15 1 21 1 40 ${IDC_EDIT_PATTERN} ${setStyle} ${CWS_NONE}
    then
        ctrl="${p2}"
        cui_window_create      "${ctrl}"
        cui_edit_settext       "${ctrl}" "${setValue}"
    fi

    # create listbox
    if cui_listbox_new "${dlg}" "" 1 3 30 4 ${IDC_LISTBOX} ${CWS_NONE} ${CWS_BORDER}
    then
        ctrl="${p2}"
        cui_listbox_callback   "${ctrl}" "${LISTBOX_CHANGED}" "${dlg}" listbox_changed
        cui_window_setcolors   "${ctrl}" "MENU"
        cui_window_create      "${ctrl}"
        # add schedule from sellist
        echo "${sellist}" |
        while read schedule
        do
            cui_listbox_add    "${ctrl}" "${schedule}"
        done
        # set value or hide listbox
        if [ ${setChecked} = 0 ]
        then
            cui_listbox_select "${ctrl}" "${value}"
        else
            cui_window_hide    "${ctrl}" 1
        fi
    fi

    # create OK button
    if cui_button_new "${dlg}" "&OK" 5 8 10 1 ${IDC_BUTOK} ${CWS_DEFOK} ${CWS_NONE}
    then
        ctrl="${p2}"
        cui_button_callback    "${ctrl}" "${BUTTON_CLICKED}" "${dlg}" ok_button_clicked
        cui_window_create      "${ctrl}"
    fi

    # create CANCEL button
    if cui_button_new "${dlg}" "&Cancel" 17 8 10 1 ${IDC_BUTCANCEL} ${CWS_DEFCANCEL} ${CWS_NONE}
    then
        ctrl="${p2}"
        cui_button_callback    "${ctrl}" "${BUTTON_CLICKED}" "${dlg}"  cancel_button_clicked
        cui_window_create      "${ctrl}"
    fi

    cui_return 1
}

# ----------------------------------------------------------------------------
# exec_dailog
# ece --> request to create and execute dialog
#         $p2 --> main window handle
#         $p3 --> name of config variable
# ----------------------------------------------------------------------------

exec_dialog()
{
    local win="${p2}"
    local res="${IDCANCEL}"

    # create window
    if cui_window_new "${p2}" 0 0 40 16 $((${CWS_POPUP} + ${CWS_CENTERED} + ${CWS_BORDER}))
    then
        local dlgwin="${p2}"
        cui_window_setcolors   "${dlgwin}" "DIALOG"
        cui_window_settext     "${dlgwin}" "Select your action"
        cui_window_sethook     "${dlgwin}" "${HOOK_CREATE}"  testdlg_create_hook
        cui_window_create      "${dlgwin}"

        cui_window_modal       "${dlgwin}"
        res="${p2}"
        cui_window_destroy     "${dlgwin}"
    fi

    cui_return "${res}"

}

# ----------------------------------------------------------------------------
# Create the selection list
# ----------------------------------------------------------------------------

create_selection()
{
    sellist='yes
    no
    86400'
}

# ----------------------------------------------------------------------------
# Main routine
# ----------------------------------------------------------------------------

sellist=''

create_selection

cui_init
cui_run

# ----------------------------------------------------------------------------
# end
# ----------------------------------------------------------------------------

exit 0
